@@ -224,10 +224,8 @@ Job_TC*** split_job_list (Job_TC *job, int ns)
   jl[0]=vcalloc (2, sizeof (Job_TC*));
   
   nj=queue2n(job);
- 
-  if   (nj==0)return NULL;
-  else split=(nj/ns)+1;
-   
+  split=(nj/ns)+1;
+     
   n=a=u=0;
   jl[a][0]=job;
   while (job)
@@ -335,7 +333,7 @@ int **n2splits (int splits, int tot)
 /* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*2012-02-16 18:52:59. */
+/*2012-07-12 19:05:45. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
